---
title: tutorial
description: a tutorial to using rovr
---

this tutorial will guide you through the basic usage of `rovr`.

## panel traversal

`rovr` uses a background-highlighted option to show your currently selected item, and switches to a different colored text when unfocused.

### travelling in lists

- move cursor right/select option: `l` or `right` arrow key
- move cursor left: `h` or `left` arrow key
- move cursor up: `k` or `up`
- move cursor down: `j` or `down`
- go to the first item: `g` or `home`
- go to the last item: `shift+g` or `end`

### unique to the main file list

- go up the file tree: `h` or `left` arrow key
- go down the file tree: `l`, `right` arrow key, or `enter`
- go back in history: `backspace` or `u`
- go forwards in history: `space`
- pin the currently focused folder: `shift+p`
- reload file list: `ctrl+r`

for more details on the user interface, see the [user interface guide](/rovr/guides/user-interface).

for a full list of actions and their keybindings, refer to the [file operations guide](/rovr/guides/file-operations) and the [keybindings reference](/rovr/reference/keybindings).
